@@ -15,6 +15,7 @@ column.definition <- c(index=0, select=1, vars=2, var.labs=3, msr=4, msr.image=5
   }
   rzSettings$load()
   gtkAccelMapLoad(file.path(rzSettings$getRzPath(), "themes", "Default", "gtk-2.0-key", "key.txt"))
+  
   txt1 <- "################################ Rz ################################"
   txt2 <- gettext("Excute Rz() to start,")
   txt3 <- gettext("or you can start from menu bar if you use R on Windows.")
@@ -22,5 +23,9 @@ column.definition <- c(index=0, select=1, vars=2, var.labs=3, msr=4, msr.image=5
   txt  <- format(c(txt1,txt2,txt3,txt4), justify="centre")
   txt  <- paste(txt, collapse="\n")
   packageStartupMessage(txt)
+  if (interactive()) {
+    Rz()
+    checkConfDir()
+  }
 }
 
